@@ -598,11 +598,14 @@ eel_show_yes_no_dialog (const char *question,
 			const char *no_label,
 			GtkWindow *parent)
 {
-	return show_message_dialog (question,
-				    dialog_title == NULL ? _("Question") : dialog_title, 
-				    GTK_MESSAGE_QUESTION,
-				    GTK_BUTTONS_YES_NO, NULL, 0,
-				    parent);
+	GtkDialog *dialog = 0;
+	dialog = eel_create_question_dialog (question,
+					     dialog_title == NULL ? _("Question") : dialog_title,
+					     no_label, GTK_RESPONSE_CANCEL,
+					     yes_label, GTK_RESPONSE_YES,
+					     GTK_WINDOW (parent));
+	gtk_widget_show (GTK_WIDGET (dialog));
+	return dialog;
 }
 
 /**
